@@ -1,6 +1,6 @@
 package Map::Tube;
 
-$Map::Tube::VERSION   = '3.83';
+$Map::Tube::VERSION   = '3.84';
 $Map::Tube::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Map::Tube - Lightweight Routing Framework.
 
 =head1 VERSION
 
-Version 3.83
+Version 3.84
 
 =cut
 
@@ -77,7 +77,8 @@ documented in L<Map::Tube::Cookbook>.
     | Mohammad Sajid Anwar | MANWAR   | 7 (Barcelona, Delhi, Kolkatta, London,   |
     |                      |          | Madrid, NYC, Tokyo)                      |
     |                      |          |                                          |
-    | Gisbert W Selke      | GWS      | 4 (Beijing, Glasgow, KoelnBonn, Lyon)    |
+    | Gisbert W Selke      | GWS      | 5 (Beijing, Glasgow, Hamburg, KoelnBonn, |
+    |                      |          | Lyon)                                    |
     |                      |          |                                          |
     | Renee Baecker        | RENEEB   | 1 (Frankfurt)                            |
     |                      |          |                                          |
@@ -94,6 +95,8 @@ documented in L<Map::Tube::Cookbook>.
     | FUNG Cheok Yin       | CYFUNG   | 1 (Hong Kong)                            |
     |                      |          |                                          |
     | Vitali Peil          | VPEIL    | 1 (Bielefeld)                            |
+    |                      |          |                                          |
+    | Giuseppe Di Terlizzi | GDT      | 1 (Rome)                                 |
     +----------------------+----------+------------------------------------------+
 
 =cut
